@@ -1,6 +1,6 @@
 from .bootstrap import bootstrap_odoo
+from .config import set_odoo_config
 from .launch import launch_odoo
-from .makedev import makedec_cli_app
 from .rpc import rpc_cli_app
 from .shell import odoo_shell, uninstall_modules
 from .source_get import get_source, get_source_file, install_module_dependencies
